Re: checkout-cache -f: a better way?
- From
Linus Torvalds <torvalds@osdl.org>
- Date
- May 21, 2005, 01:44 UTC
- Message-ID
- <Pine.LNX.4.58.0505201841550.2206@ppc970.osdl.org>
- In-Reply-To
- <428E7994.1090402@pobox.com>
On Fri, 20 May 2005, Jeff Garzik wrote:
> > Yep, thanks. Script does seem faster now.
Yeah. They "seem faster".
> real 0m7.069s
to
> real 0m0.389s
That's what, 20 times faster?
More, actually, I suspect, since the "-m" version is not only faster, but it doesn't do much IO, so you'll not have tons of dirty pages/inodes etc afterwards.
Linus